@@ -6,7 +6,7 @@ from .base import *
 DEBUG = True
 SECRET_KEY = "Fake Key"
 
-
+{% if debug_toolbar %}
 # django-debug-toolbar
 # ----------------------------------------------------------------------------------------------------------------------
 INSTALLED_APPS += ["debug_toolbar"]
@@ -15,3 +15,4 @@ DEBUG_TOOLBAR_CONFIG = {
     "SHOW_TEMPLATE_CONTEXT": True,
 }
 INTERNAL_IPS = ["127.0.0.1", "10.0.2.2"]
+{% endif %}
\ No newline at end of file
